# Kobo
A hugo-like markdown website/blog builder + server

# Features
- Built with Flask
- Native support for markdown using katex
- No customization -> forced to use the best web theme you've ever seen

# Installation
1. Run `python3 -m pip install kobo-md`
2. Install katex via `npm install katex`

# Usage
- To start a new project, simply enter the target directory and run `python3 -m katex new`.
- To compile markdown files into html snippets, run `python3 -m katex compile`.
- To run the server, run `python3 -m katex server` from the project directory.
